
#!/usr/bin/env python

# Create MISMIP+ run script, this script is based on the MISMIP3d createscript.py in PISM examples 
# johannes.feldmann@pik-potsdam

import argparse
import os
import shutil
import subprocess
import sys

# process command line arguments
parser = argparse.ArgumentParser(description='Create run script for a MISMIP+ experiment.',
                                 formatter_class=argparse.ArgumentDefaultsHelpFormatter)
parser.add_argument('-a', '--accumrate', metavar='A', type=float, default=0.3,
                    help='accumulation rate in meters/year')
parser.add_argument('-C', '--frictioncoeff', metavar='', type=float, default=3.16e6,
                    help='Friction coefficient (beta^2)')
parser.add_argument('-m', '--frictionexpon', metavar='', type=float, default=1./3.,
                    help='Friction exponent (m^-1)')
parser.add_argument('-O', '--mrfactor', metavar='', type=float, default=0.2,
                    help='Melt-rate factor (yr^-1)')
parser.add_argument('-A', '--softness', metavar='IS', type=float, default=6.338e-25,
                    help='Ice softness') 
parser.add_argument('-w', '--channelwidth', metavar='W', type=float, default=24.0,
                    help='Channel width (km)')
parser.add_argument('-d', '--channeldepth', metavar='W', type=float, default=500.0,
                    help='Channel depth compared with sidewalls (m)')
parser.add_argument('-y', '--slopeheight', metavar='W', type=float, default=150.0,
                    help='Elevation difference of reverse slope (m)')
parser.add_argument('--yo', metavar='yo', type=float, default=0.0,
                    help='Offset for basal topography (m)')
parser.add_argument('--vs', metavar='vs', type=float, default=1.0,
                    help='Scale vertical dimension (ice thickness and bed topography)')
parser.add_argument('--hs', metavar='hs', type=float, default=1.0,
                    help='Scale horizontal dimension (bed topography)')
parser.add_argument('--ss', metavar='hs', type=float, default=1.0,
                    help='Scale slope length')
parser.add_argument('-e', default='Spinup', 
                    choices=['Prespin', 'Spinup', 'Pert', 'Rela', 'Step0', 'Step-5', 'Step-10', 'Step-15', 'Step-20', 'Step-40', 'Step-60', 'Step-80', 'Step-100', 'Step-120', 'Step-140', 'Step-160', 'Step-180', 'Step-200', 'Step-220', 'Step-240', 'Step-260', 'Step-280', 'Step-300', 'Step-320', 'Step-340', 'Step-360', 'Step-380', 'Step-400', 'DBc', 'DBp', 'DBr', 'DBk', 'DBm'],
                    help='name of experiment')
parser.add_argument('-t', choices=[1, 2], type=int, default=2,
                    help='model; 1 = SSA only, 2 = hybrid SIA+SSA')
parser.add_argument('-b', '--tsai', action='store_true',  # thus defaults to False
                    help='Use Tsai modification of pseudo-plastic friction law')
parser.add_argument('-r', type=float, choices=[0.25,0.5, 1, 2, 4, 5, 8, 10, 16], default=1,
                    help='model resolution in km')
# parser.add_argument('-r', type=int, choices=[1, 2, 3, 4, 5], default=2,
#                     help='resolution mode; 1 = finest, 6 = coarsest')
parser.add_argument('-s', '--subgl', action='store_true',  # thus defaults to False
                    help='use sub-grid grounding line method')
parser.add_argument('--sm', action='store_true',  # thus defaults to False
                    help='use sub-grid grounding line method + sub-grid melting')
parser.add_argument('-g', default='eta',
                    choices=['eta', 'haseloff', 'mahaffy'])
parser.add_argument('--ssagrad', choices=['one_sided','GL_one_sided','GL_centered_thk','GL_centered_surf'],
                    type=str, default='GL_centered_thk', help='Gradient method')

parser.add_argument('--wadd', metavar='W', type=float, default=0.0,
                    help='Widening of channel (km)')
parser.add_argument('--wp', metavar='W', type=float, default=0.0,
                    help='Widening of channel (km)')

parser.add_argument('--Amod', metavar='W', type=float, default=0.0,
                    help='Modified ice softness')

parser.add_argument('--xpp', type=float, default=700.0,
                    help='x coordinate of pinning point center (km)')
parser.add_argument('--ypp', type=float, default=160.0,
                    help='y coordinate of pinning point center (km)')
parser.add_argument('--wpp', type=float, default=15.0,
                    help='width of pinning point (km)')
parser.add_argument('--hpp', type=float, default=20.0,
                    help='surface elevation of pinning point center (m)')
parser.add_argument('--bw', action='store_true',  # thus defaults to False
                    help='make backwards step in hysteresis')

parser.add_argument('--pythonpath', metavar='PATH', default='python',
                    help='full path to python executable')
parser.add_argument('-S', '--submit', action='store_true', default=False,
                    help='Submit run')
parser.add_argument('-W', '--wallclock', metavar='WC', type=str, default="0-23:55:00",
                    help='Wall clock time for submission') 
parser.add_argument('-T', '--runtype', choices=["short", "medium", "long", "priority", "standby"], type=str, default="short",
                    help='Type of run') 
parser.add_argument('-N', '--ncores', type=int, default=16,
                    help='Number of cores')
parser.add_argument('-P', default='haswell', choices=['haswell', 'broadwell'], help='name of cluster partition')


args = parser.parse_args()
# print args   # helpful for debugging

numC=32 if args.P=="broadwell" else 16

# key: resolution mode; parameters: (resolution in km, Mx, My)
grid_parameters = {0.25: (0.25,    5601, 1281),
                   0.5: (0.5,    3201, 641),
                   1: (1,      1601, 321),
                   2: (2,      int(args.hs*800 + 1),  161),
                   4: (4,      401,  81),
                   5: (5,      321, 65),
                   8: (8,      201,  41),
                   10: (10,     161,  33),
                   16: (16,     101,  21)}

Flist = "0,0.0000001"
for k in range(1000,1000001,1000):
    Flist += ","+str(k)

Flist100 = "0,0.0000001"
for k in range(100,1000001,100):
    Flist100 += ","+str(k)

Flist10 = "0,0.0000001"
for k in range(100,100001,10):
    Flist10 += ","+str(k)

Flist1 = "0,0.0000001"
for k in range(1,10001,1):
    Flist1 += ","+str(k)

Flist05 = "0:0.1:0.5"

etimelist = {'Prespin': (0, 1000000, Flist, ""),
             'Step0': (0, 1000000, Flist, "", ""),
             'Step-5': (0, 1000000, Flist, "", ""),
             'Step-10': (0, 1000000, Flist, "", ""),
             'Step-15': (0, 1000000, Flist, "", ""),
             'Step-20': (0, 1000000, Flist, "", ""),
             'Step-40': (0, 1000000, Flist, "Step-20", "-20.0"),
             # 'Step-40': (0, 1000000, Flist, "Prespin", "-20.0"),
             'Step-60': (0, 1000000, Flist, "Step-40", "-40.0"),
             'Step-80': (0, 1000000, Flist, "Step-60", "-60.0"),
             'Step-100': (0, 1000000, Flist, "Step-80", "-80.0"),
             'Step-120': (0, 1000000, Flist, "Step-100", "-100.0"),
             # 'Step-120': (0, 1000000, Flist, "Prespin", "-100.0"),
             'Step-140': (0, 1000000, Flist, "Step-120", "-120.0"),
             'Step-160': (0, 1000000, Flist, "Step-140", "-140.0"),
             'Step-180': (0, 1000000, Flist, "Step-160", "-160.0"),
             'Step-200': (0, 1000000, Flist, "Step-180", "-180.0"),
             'Step-220': (0, 1000000, Flist, "Step-200", "-200.0"),
             'Step-240': (0, 1000000, Flist, "Step-220", "-220.0"),
             'Step-260': (0, 1000000, Flist, "Step-240", "-240.0"),
             'Step-280': (0, 1000000, Flist, "Step-260", "-260.0"),
             'Step-300': (0, 1000000, Flist, "Step-280", "-280.0"),
             'Step-320': (0, 1000000, Flist, "Step-300", "-300.0"),
             'Step-340': (0, 1000000, Flist, "Step-320", "-320.0"),
             'Step-360': (0, 1000000, Flist, "Step-340", "-340.0"),
             'Step-380': (0, 1000000, Flist, "Step-360", "-360.0"),
             'Step-400': (0, 1000000, Flist, "Step-380", "-380.0"),
             'DBc': (0, 0.5, Flist05, "DBc", ""),
             'DBp': (0, 0.5, Flist05, "DBp", ""),
             'DBr': (0, 5, Flist1, "DBr", ""),
             'DBk': (0, 5, Flist1, "DBk", ""),
             'DBm': (0, 5, Flist1, "DBm", ""),
             'Spinup': (0, 50000, Flist, "Prespin"),
             'Pert': (0, 50000, Flist, "Prespin"),
             'Rela': (0, 50000, Flist, "Pert")}

stimelist = {'Prespin': (0, 1000000, "0:1000:1000000"),
             'Step0': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-5': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-10': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-15': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-20': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-40': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-60': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-80': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-100': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-120': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-140': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-160': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-180': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-200': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-220': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-240': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-260': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-280': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-300': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-320': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-340': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-360': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-380': (0, 1000000, Flist, "0:1000:1000000"),
             'Step-400': (0, 1000000, Flist, "0:1000:1000000"),
             'DBc': (0, 0.5, Flist05),
             'DBp': (0, 0.5, Flist05),
             # 'DBp': (0, 100, "0:1:5"),
             'DBr': (0, 100, "0:0.1:0.5"),
             # 'DBr': (0, 100, "0:1:5"),
             'DBk': (0, 10, "0:1:5"),
             'DBm': (0, 100, "0:1:5"),
             'Spinup': (0, 50000, "0:1000:50000"),
             'Pert': (0, 50000, "0:1000:50000"),
             'Rela': (0, 50000, "0:1000:50000")}

# etimelist = {'Prespin': (0, 100000, Flist, ""),
#              'Spinup': (0, 50000, Flist, "Prespin"),
#              'Pert': (0, 50000, Flist, "Prespin"),
#              'Rela': (0, 50000, Flist, "Pert")}

# stimelist = {'Prespin': (0, 100000, "0:10000:100000"),
#              'Spinup': (0, 50000, "0:1000:50000"),
#              'Pert': (0, 50000, "0:1000:50000"),
#              'Rela': (0, 50000, "0:1000:50000")}
 

sub="_Subgl" if args.subgl else "_NoSubgl"
subm="_SubglMelt" if args.sm else ""
tsai="_Tsai" if args.tsai else ""
type="_onlySSA" if args.t==1 else ""
grad="_"+args.g if args.g!='eta' else ""

ename = 'Back'+args.e if args.bw == True else args.e

fname = "%s_a%s_A%2.3e_C%2.3e_w%s_d%s_dy%s_hs%s_xpp%s_ypp%s_wpp%s_hpp%s_r%skm%s%s%s%s_dscenteredthk_noeta_msl" %(ename, args.accumrate, args.softness, args.frictioncoeff, args.channelwidth, args.channeldepth, args.slopeheight, args.hs, args.xpp, args.ypp, args.wpp, args.hpp, grid_parameters[args.r][0], sub, subm, tsai, type)

if not os.path.exists(fname):
    os.makedirs(fname+"/log")
else:
    ans = raw_input("Directory already existing. Overwrite [Y]/n? ") or "y"
    if ans in {"y", "Y", "yes", "Yes"}:
        shutil.rmtree(fname)
        os.makedirs(fname+"/log")

    else:
        print "Aborting ..."
        sys.exit()

cmdfile = open(fname+"/log/RunCommand.txt", "w")
for ar in sys.argv[:]:
    cmdfile.write(ar+" ")

#############################################################################################
# create file into which printed output from this script will be directed to
sname = "./runPism.sh"
ofile = open(sname, 'w')
sys.stdout = ofile

print """#!/bin/bash
###### MISMIP+ run script for experiment %s, model %d, and resolution mode %d ######

accumrate=%s""" % (args.e, args.t, args.r, args.accumrate)

print 'filename="%s"' % fname

Lx = 800 + grid_parameters[args.r][0]*0.5
Ly = 160 + grid_parameters[args.r][0]*0.5

# note My is ignored if args.e=='Stnd'
print """
# Grid
resolution=%f # resolution in km
Mx=%d
My=%d""" % grid_parameters[args.r]

print """
# Friction parameters
C=%f 
m=%f""" % (args.frictioncoeff, args.frictionexpon)

print '# Ice softness'
print 'A=%e'  % (args.softness)
if args.Amod > 0:
    print 'A=%e'  % (args.Amod)
print '# Channel width'
print 'w=%f' % (args.channelwidth)
print 'wadd=%f' % (args.wadd)
print 'weff=%f' % (args.channelwidth + args.wadd + args.wp)
print 'd=%f' % (args.channeldepth)
print 'dy=%f' % (args.slopeheight)
print 'vs=%f' % (args.vs)
print 'hs=%f' % (args.hs)
print 'ss=%f' % (args.ss)
print 'xpp=%f' % (args.xpp)
print 'ypp=%f' % (args.ypp)
print 'wpp=%f' % (args.wpp)
print 'hpp=%f' % (args.hpp)
print 'ssagrad=%s' % (args.ssagrad)
if args.e in {'Pert', 'DBp', 'DBk', 'DBm'}:
    print 'tpp=0.0'
else:
    print 'tpp=1.0'
if ename == 'BackDBp':
    print 'tpp=1.0'
    print 'hpp=%f' %(-100.0)
# print 'yo=%f' % (args.yo)

print '# Ocean parameters'
if args.e in {'Ice2r', 'Ice2rr'}:
        print 'meltr=100.0 # sub-shelf melt rate'
        print 'bound=480000.0 # boundary with upstream sub-shelf melting equals zero'
        print 'Omega=0.0'
else:
    if args.e in {'Prespin', 'Spinup', 'Pert', 'Rela', 'Ice0', 'Ice1ra', 'Ice1raL', 'Ice1raLF', 'Ice2ra', 'Ice2raL','Ice3r','Ice3ra'}:
        print 'Omega=0.0'
    else:
        print 'Omega=%f # Melt-rate factor (yr^-1)' % args.mrfactor
    print 'H0=75 # Reference ocean cavity thickness in m'
    print 'z0=-100 # Depth above which the melt rate is zero in m'

print ''
if args.subgl:
    print '# subgrid grounding line interpolation is used'
    if args.sm:
        print '# subgrid melt is applied'
        print 'subgl="-subgl"'
    else:
        print '# subgrid melt is NOT applied'
        print 'subgl="-subgl -no_subgl_basal_melt"'

else:
    print '# subgrid grounding line interpolation is not used'
    print 'subgl=" "'

print ''
if args.tsai:
    print '# Tsai modification of pseudo-plastic friction law is used'
    print 'tsai="-pseudo_plastic_tsai_mod -pseudo_plastic_tsai_f 0.5"'
else:
    print '# Pure pseudo-plastic friction law is used'
    print 'tsai=" "'

print '# Gradient method'
print 'grad=%s' % (args.g)

print '# create config file ...'
print '%s ../preprocess_ssagrad.py -A $A' %args.pythonpath

print ''
# print '%s ../setup_Spinup_neat_vertscale.py -a $accumrate -r $resolution -w $weff -d $d -y $dy --ss $ss' % args.pythonpath
print '%s ../setup_Spinup_neat_vertscale_ssagrad.py -a $accumrate -r $resolution -w $weff -d $d -y $dy --hs $hs --xpp $xpp --ypp $ypp --wpp $wpp --hpp $hpp --tpp $tpp' % args.pythonpath
# print '%s ../setup_Spinup_neat_vertscale.py -a $accumrate -r $resolution -w $weff -d $d -y $dy --vs $vs' % args.pythonpath
# print '%s ../setup_Spinup_neat.py -a $accumrate -r $resolution -w $weff -d $d -y $dy --yo $yo' % args.pythonpath
# if args.e in {'Prespin'}:
#     print '# create bootstrap file using python ...'
# else:
#     print '# NOT creating bootstrap file since experiment %s starts from previously-saved state' % args.e

    
# print '%s ../setup_Spinup.py -a $accumrate -r 1 -w $w' % args.pythonpath
# print '%s ../setup_Spinup.py -a $accumrate -r $resolution -w $w' % args.pythonpath

print 'starty=%s' % etimelist[args.e][0]
print 'duration=%s' % etimelist[args.e][1]
print 'etimes=%s' % etimelist[args.e][2]
print 'stimes=%s' % stimelist[args.e][2]

print ''
# print 'listexvar="thk,topg,usurf,velbar,mask"'
print 'listexvar="thk,topg,usurf,velbar,mask,deviatoric_stresses"'
# print 'listexvar="thk,topg,usurf,velbar_mag,mask,deviatoric_stresses,taub,taud"'

print 'extrastuff="-extra_times $etimes -extra_vars $listexvar"' 

print 'results="-save_file results/year -save_times $stimes -save_split -save_size small"'

print ''
print 'stressbalance="-ssa_method fd -ssa_flow_law isothermal_glen -ssafd_ksp_rtol 1e-7"'
print 'basal="-yield_stress constant -tauc $C -pseudo_plastic -pseudo_plastic_q $m -pseudo_plastic_uthreshold 3.1556926e+07"'
print 'calvingfront="-cfbc -part_grid -kill_icebergs"'
if args.e in {'Ice3r'}:
    print 'calvingfront="-cfbc -part_grid -calving float_kill"'

if args.t == 1:
    print 'modelopt="-stress_balance ssa" '
elif args.t == 2:
    print 'modelopt="-stress_balance ssa+sia -sia_flow_law isothermal_glen"'

print 'STRONGKSP="-ssafd_ksp_type gmres -ssafd_ksp_norm_type unpreconditioned -ssafd_ksp_pc_side right -ssafd_pc_type asm -ssafd_sub_pc_type lu"'

print ''
print 'opts="-config_override input/MISMIP+_conf.nc $stressbalance $basal $calvingfront $subgl $tsai $modelopt -energy none -ssa_gradient $ssagrad -options_left -ts_file extras/ts_%s.nc -ts_times $starty:1:$duration -extra_file extras/ex_%s.nc $extrastuff $results -ye $duration -o_order zyx -o_size small -o results/%s.nc -skip -skip_max 10 $results $STRONGKSP -backup_interval 8"' % (ename, ename, ename)

print """
##############################

###### CREATE DIRECTORIES ######

WORKDIR=/p/tmp/johfeld/pismOut/GroundingLineStability

cd ..

RUNNAME=`echo $PWD | awk -F/ '{print $NF}'`
OUTDIR=$WORKDIR/$RUNNAME/$filename
INDIR=$WORKDIR/Calibration/$filename

echo $OUTDIR

cd $filename

###### Create output directory and copy executable and source
restart=false
if ! $restart ; then
  rm -r $OUTDIR
fi
mkdir -p $OUTDIR/bin
mkdir -p $OUTDIR/src
mkdir -p $OUTDIR/input
mkdir -p $OUTDIR/results
mkdir -p $OUTDIR/output
mkdir -p $OUTDIR/extras

pismver=`echo $PWD | awk -F_ '{print $1}' | awk -F/ '{print $NF}'`
codever=`echo $PWD | awk -F_ '{print $2}'`
thisdir=`echo $PWD`

####### PISM version ######
rsync -aCv /home/johfeld/pismDev/driving_stress_schemes_2020_mismip+_dist_lathalf/bin/pismr ${OUTDIR}/bin/
rsync -aC  /home/johfeld/pismDev/driving_stress_schemes_2020_mismip+_dist_lathalf/src $OUTDIR
# rsync -aCv /home/johfeld/pismDev/opttphi/bin/pismr ${OUTDIR}/bin/
# rsync -aCv /home/johfeld/pismDev/opttphi/src ${OUTDIR}

###### Input files ######
rsync -aCv MISMIP+_conf.nc ${OUTDIR}/input
rsync -aCv MISMIP+_InitialSetup.nc ${OUTDIR}/input
rsync -aCv runPism.sh ${OUTDIR}/input
rsync -aCv submission.cmd ${OUTDIR}/input
rsync -aCv slurmit ${OUTDIR}/input

###### CLUSTER COMMANDS ######
module purge
module load pism/stable1.0_broadwell
module load anaconda/2.3.0

NN=2  # default number of processors
if [ $# -gt 0 ] ; then  # if user says "antspinup.sh 8" then NN = 8
  NN="$1"
fi

###### use only MPI if job is submitted
if [ -n "${PISM_ON_CLUSTER:+1}" ]; then  # check if env var is set
  echo "$SCRIPTNAME this run was submitted, use MPI"
  # PISM_MPIDO="mpiexec.hydra -bootstrap slurm -n"
  PISM_MPIDO="srun -n"
  echo "$SCRIPTNAME      PISM_MPIDO = $PISM_MPIDO"
else
  echo "$SCRIPTNAME this is interactive, skip use of MPI"
  PISM_MPIDO=""
  NN=""
  echo "$SCRIPTNAME      PISM_MPIDO = $PISM_MPIDO"
fi
PISM_DO="$PISM_MPIDO $NN $PISM_EXEC"
#############################

cd $OUTDIR"""

print '' 

print 'PISM_EXEC="./bin/pismr"'
print 'PISM_DO="$PISM_MPIDO $NN $PISM_EXEC"'
print 'out="output/%s.out"' % args.e

if args.e == 'Prespin':
    print '''
    infile="input/MISMIP+_InitialSetup.nc"
    restart_file=year_restart_2000.000.nc
    init_opts="-i $infile -bootstrap -Mx $Mx -My $My -Mz 31 -Lz 6000"
    append=""

    if $restart ; then
      init_opts="-i $WORKDIR/$RUNNAME/$filename/results/$restart_file"
      append="-ts_append -extra_append"
    fi
    '''
    
    print 'ocean="-ocean constant -shelf_base_melt_rate 0"'
    print 'cmd="$PISM_DO $init_opts $ocean -front_retreat_file $infile $opts $append"'
    # print 'cmd="$PISM_DO -i $infile -bootstrap -Mx $Mx -My $My -Mz 31 -Lz 6000 $ocean -ocean_kill_file $infile $opts"'

else:
    if args.e in {'DBc', 'DBp', 'DBk', 'DBm'}:
        if args.bw == True:
            initname = 'BackStep%i' %args.hpp 
        else:
            initname = 'Prespin' if args.hpp == -100.0 else 'Step%i' %args.hpp

        print 'infile="$WORKDIR/$RUNNAME/%s_a%s_A%2.3e_C%2.3e_w%s_d%s_dy%s_hs%s_xpp%s_ypp%s_wpp%s_hpp%s_r%skm%s%s%s%s_dscenteredthk_noeta_msl/results/%s.nc"' %(initname, args.accumrate, args.softness, args.frictioncoeff, args.channelwidth, args.channeldepth, args.slopeheight, args.hs, args.xpp, args.ypp, args.wpp, args.hpp, grid_parameters[args.r][0], sub, subm, tsai, type, initname)
    else:
        hpp_prev = args.hpp-20
        hpp_val = hpp_prev if args.bw == True else etimelist[args.e][4]
        initname = 'BackStep%i' %hpp_prev if args.bw == True else etimelist[args.e][3]
    
        print 'infile="$WORKDIR/$RUNNAME/%s_a%s_A%2.3e_C%2.3e_w%s_d%s_dy%s_hs%s_xpp%s_ypp%s_wpp%s_hpp%s_r%skm%s%s%s%s_dscenteredthk_noeta_msl/results/%s.nc"' %(initname, args.accumrate, args.softness, args.frictioncoeff, args.channelwidth, args.channeldepth, args.slopeheight, args.hs, args.xpp, args.ypp, args.wpp, hpp_val, grid_parameters[args.r][0], sub, subm, tsai, type, initname)
        # override for alternative slope for xpp=500 starting at tipped state (hpp=-400)
        # print 'infile="$WORKDIR/$RUNNAME/%s_a%s_A%2.3e_C%2.3e_w%s_d%s_dy%s_hs%s_xpp%s_ypp%s_wpp%s_hpp%s_r%skm%s%s%s%s_dscenteredthk_noeta_msl/results/%s.nc"' %('BackStep-280', args.accumrate, args.softness, args.frictioncoeff, args.channelwidth, args.channeldepth, '150.0', args.hs, '600.0', args.ypp, args.wpp, '-280.0', grid_parameters[args.r][0], '_Subgl', subm, tsai, type, 'BackStep-280')
        # print 'infile="$WORKDIR/$RUNNAME/%s_a%s_A%2.3e_C%2.3e_w%s_d%s_dy%s_hs%s_xpp%s_ypp%s_wpp%s_hpp%s_r%skm%s%s%s%s_dscenteredthk_noeta_msl/results/%s.nc"' %('BackStep-280', args.accumrate, args.softness, args.frictioncoeff, args.channelwidth, args.channeldepth, '150.0', args.hs, '600.0', args.ypp, args.wpp, '-280.0', grid_parameters[args.r][0], sub, subm, tsai, type, 'BackStep-280')
        # print 'infile="$WORKDIR/$RUNNAME/%s_a%s_A%2.3e_C%2.3e_w%s_d%s_dy%s_hs%s_xpp%s_ypp%s_wpp%s_hpp%s_r%skm%s%s%s%s_r_neat/results/%s.nc"' %('BackStep-400', args.accumrate, args.softness, args.frictioncoeff, args.channelwidth, args.channeldepth, '150.0', args.hs, '500.0', args.ypp, args.wpp, '-400.0', grid_parameters[args.r][0], sub, subm, tsai, type, 'BackStep-400')
    
        
    print 'boot="-bootstrap -Mx $Mx -My $My -Mz 31 -Lx %s -Ly %s -Lz 6000"' %(Lx, Ly)
    print 'regrid="-regrid_file $infile -regrid_vars litho_temp,temp,enthalpy,thk"'
    print 'ocean="-ocean constant -shelf_base_melt_rate 0"'
    if args.e in {'DBm'}:
        print 'ocean="-ocean constant -shelf_base_melt_rate 1000"'
    print 'cmd="$PISM_DO -i input/MISMIP+_InitialSetup.nc $boot $regrid $ocean -front_retreat_file input/MISMIP+_InitialSetup.nc $opts"'

print '''
if $restart ; then
  restart_file=year_restart_2000.000.nc
  infile="input/MISMIP+_InitialSetup.nc"
  init_opts="-i $WORKDIR/$RUNNAME/$filename/results/$restart_file"
  append="-ts_append -extra_append"
  ocean="-ocean constant -shelf_base_melt_rate 0"
  cmd="$PISM_DO $init_opts $ocean -front_retreat_file $infile $opts $append"
  fi
'''

print ''
print 'echo "running command:"'
print 'echo $cmd'
print 'echo'

print ''
print '$cmd >> $out'
# print '$cmd'

submit = True

ofile.close()
shutil.copy(sname, fname)
shutil.copy("submission.cmd", fname)
shutil.copy("slurmit", fname)
os.chdir(fname)
if args.submit:
    subprocess.call("./slurmit %s %s %s %i %s" %(args.ncores,args.runtype,args.wallclock,numC,args.P), shell=True)
else:
    subprocess.call(sname, shell=True)
